@@ -6,7 +6,7 @@
 # raise a `RecursionError`.
 # In order to avoid this, import only the API that you directly need like:
 #
-#   from foxtail_trainer_api.api.data_set_chunk_api import DataSetChunkApi
+#   from foxtail_trainer_api.api.custom_metric_api import CustomMetricApi
 #
 # or import this package, but before doing it, use:
 #
@@ -14,6 +14,7 @@
 #   sys.setrecursionlimit(n)
 
 # Import APIs into API package:
+from foxtail_trainer_api.api.custom_metric_api import CustomMetricApi
 from foxtail_trainer_api.api.data_set_chunk_api import DataSetChunkApi
 from foxtail_trainer_api.api.job_api import JobApi
 from foxtail_trainer_api.api.ml_model_api import MLModelApi
