@@ -12,6 +12,7 @@
 from foxtail_trainer_api.model.add_or_update_model_hyperparameter import AddOrUpdateModelHyperparameter
 from foxtail_trainer_api.model.add_or_update_model_hyperparameter_in_job import AddOrUpdateModelHyperparameterInJob
 from foxtail_trainer_api.model.aggregated_metric_report_dto import AggregatedMetricReportDto
+from foxtail_trainer_api.model.create_custom_metric_dto import CreateCustomMetricDto
 from foxtail_trainer_api.model.create_data_sets_sizes_dto import CreateDataSetsSizesDto
 from foxtail_trainer_api.model.create_job_command import CreateJobCommand
 from foxtail_trainer_api.model.create_ml_model_dto import CreateMLModelDto
@@ -26,6 +27,7 @@ from foxtail_trainer_api.model.create_training_result_dto import CreateTrainingR
 from foxtail_trainer_api.model.created_job_dto import CreatedJobDto
 from foxtail_trainer_api.model.created_ml_models_dto import CreatedMLModelsDto
 from foxtail_trainer_api.model.created_prediction_task_dto import CreatedPredictionTaskDto
+from foxtail_trainer_api.model.custom_metric_dto import CustomMetricDto
 from foxtail_trainer_api.model.custom_model_hyperparameter_dto import CustomModelHyperparameterDto
 from foxtail_trainer_api.model.custom_model_hyperparameter_with_model_dto import CustomModelHyperparameterWithModelDto
 from foxtail_trainer_api.model.data_set_chunk_basic_dto import DataSetChunkBasicDto
